@@ -2348,7 +2348,7 @@ dialog_response_cb (GtkWidget *widget,
 
   if (response_id == GTK_RESPONSE_HELP)
     {
-      empathy_url_show (widget, "ghelp:empathy?accounts-window");
+      empathy_url_show (widget, "help:empathy/accounts-window");
     }
   else if (response_id == GTK_RESPONSE_CLOSE ||
       response_id == GTK_RESPONSE_DELETE_EVENT)
@@ -2465,6 +2465,7 @@ accounts_dialog_build_ui (EmpathyAccountsDialog *dialog)
   gtk_widget_show (priv->infobar);
 
   grid = gtk_grid_new ();
+  gtk_grid_set_column_spacing (GTK_GRID (grid), 6);
   gtk_container_add (
       GTK_CONTAINER (gtk_info_bar_get_content_area (
           GTK_INFO_BAR (priv->infobar))),
