@@ -2052,7 +2052,7 @@ static void
 roster_window_help_contents_cb (GtkAction *action,
     EmpathyRosterWindow *self)
 {
-  empathy_url_show (GTK_WIDGET (self), "ghelp:empathy");
+  empathy_url_show (GTK_WIDGET (self), "help:empathy");
 }
 
 static gboolean
@@ -2425,7 +2425,7 @@ hide_contacts_loading (EmpathyRosterWindow *self)
 {
   gtk_spinner_stop (GTK_SPINNER (self->priv->spinner_loading));
 
-  display_page_contact_list (self);
+  set_notebook_page (self);
 }
 
 static void
